Package 'survivalVignettes'

Title: Survival Analysis Vignettes and Optional Datasets
Description: Vignettes for the 'survival' package. Split from the 'survival' package since the vignettes were getting large. Also, since 'survival' is a recommended package it cannot make use of other packages outside of base+recommended (e.g. 'rmarkdown').
Authors: Terry M Therneau [aut], Elizabeth Atkinson [cre, ctb], Cynthia Crowson [ctb]
Maintainer: Elizabeth Atkinson <[email protected]>
License: LGPL (>=2)
Version: 0.3.0
Built: 2026-06-06 15:19:14 UTC
Source: https://github.com/bethatkinson/survivalvignettes

Help Index


Survival Analysis Vignettes and Optional Datasets

Description

Vignettes for the 'survival' package. Split from the 'survival' package since the vignettes were getting large. Also, since 'survival' is a recommended package it cannot make use of other packages outside of base+recommended (e.g. 'rmarkdown').

Author(s)

Terry M Therneau [aut], Elizabeth Atkinson [cre, ctb], Cynthia Crowson [ctb]

Maintainer: Elizabeth Atkinson <[email protected]>


Survival with amyloidosis

Description

This pair of data sets is used in the external validation vignette. The amyloidmodel dataset contains survival curves from four studies, the amyloid data survival times and risk scores for 1005 subjects.

Usage

amyloid
amyloidmodel

Format

The amyloid object is a data frame with 1005 observations on the following 8 variables.

age

age in years

month

survival time in months

status

0= censored, 1= death

number.organs

number of involved organ systems

r2004

patient stage based on the 2004 model

r2012

patient stage based on the 2012 model

r2013

patient stage based on the 2013 model

r2015

patient stage based on the 2015 model

year

diagnosis year

The amyloidmodel object is a data frame with 832 observations on the following 4 variables.

study

which study: 2004, 2012, 2013 or 2015

stage

disease stage

month

months from study entry

survival

predicted survival

Details

The model assement is found in Muchtar (2019), and used as an example in a package vignette. Patients with biopsy proven systemic light chain (AL) amyloidosis seen at the Mayo Clinic from 2003-01-01 to 31-08-2015 were screened for the study. The final study cohort includes all those without prior chemotherapy and with the necessary baseline data to assign patient stage, using each of the four systems.

The survival curves from the staging systems were (impefectly) digitized from the relevant papers. The 2013 publication is from a trial involving only stage 2 subjects and divided them as IIIa, IIIb and IIIc (stage 2-4 in our notation). The 2015 paper is also from a clinical trial and has 0/30 deaths in the stage 0 subjects. They label the stages as I, II, IIIa and IIIb where we have used 0-3 for consistency with the original 2004 system.

References

E Muchtar, T Therneau, D Larson, M Gertz, M Lacy, F buadi, D Dingli, S Hayman, P Kapoor, W Gonsalves, T Kourelis, R Warsame, A Fonder, M Hobbs, Y Hwa, N Leung, S Russell, J Lust, Y Lin, R Go, S Zelderust, R Kyle, S V Rajkumar, S K Kumar, A Dispezieri. Comparitive analysis of staging systems in AL amyloidosis. Leukemia (2019) 33:811-814. doi:10.1038/s41375-018-0370-z

A Dispenzieri 2004, doi:10.1200/JCO.2004.03.029 S Kumar 2012, doi:10.1200/JCO.2011.38.5724 A Wechalekar 2013, doi:10.1182/blood-2012-12-473066 M Palladini 2015, doi: 10.1182/blood-2015-01-620302

Examples

sfit <- survfit(Surv(month, status) ~ r2012, data = amyloid)
plot(sfit, lty=1:4, col=1:4, lwd=2, log=TRUE,
     xlab="Months from diagnosis", ylab="Survival")

Survival after Serum Protein Electrophoresis (SPE) test

Description

This data is used in the poisson vignette. Monoclonal gammopathy of undetermined significance (MGUS) is detected from the serum protein electrophoresis (SPE test), which is ordered by a physician for a number of reasons. This dataset contains survival information for 23,294 Southeastern Minnesota residents who had the SPE test ordered between 1971 and 1994. Of those, 1384 were diagnosed with MGUS at Mayo Clinic.

Usage

data("spe")

Format

A data frame with 23294 observations on the following 7 variables.

id

subject id

age

age in years for when the test was ordered. Ages >85 are summarized as 85.

sex

male or female

mgus

1=MGUS diagnosis

testyr

test year

futime

days from test to last follow-up

death

1=follow-up is until death

Details

Plasma cells are responsible for manufacturing immunoglobulins, an important part of the immune defense. At any given time there are estimated to be about 106106 different immunoglobulins in the circulation at any one time. When a patient has a plasma cell malignancy the distribution will become dominated by a single isotope, the product of the malignant clone, visible as a spike on a serum protein electrophoresis. Monoclonal gammopathy of undetermined significance (MGUS) is the presence of such a spike, but in a patient with no evidence of overt malignancy. This dataset is an anonymized version of the data from approximately 1971 to 1994. Some values have been changed slightly.

Mayo Clinic data courtesy of Dr. Robert Kyle.

References

R Kyle, Benign monoclonal gammopathy – after 20 to 35 years of follow-up, Mayo Clinic Proc 1993; 68:26-36.

Examples

library(survival)
sfit <- survfit(Surv(futime,death) ~ mgus, data=spe)
print(sfit, scale=365)